"""
Copilot-Kommentarblock:
Dieses Modul `xjustiz2pdf` konvertiert XJustiz-Akten (XML/ZIP) in eine Gesamt-PDF.
Es enthält Parser, PDFBuilder, Worker, Utils und eine Qt-GUI.
Die Datei __init__.py definiert die Paketversion und macht das Modul importierbar.
"""

__version__ = "0.1.2"
__debugstate__ = False
